[recipe_wrapper] Rename led-edit-recipe-wrapper

Clean up some trailing references, this script does not work without
this rename.

Bug: b/294422701
Change-Id: Ic5400771c839dc69f01fc6da555fbdff8965792a
Reviewed-on: https://fuchsia-review.googlesource.com/c/infra/infra/+/896800
Reviewed-by: Oliver Newman <olivernewman@google.com>
Fuchsia-Auto-Submit: Anthony Fandrianto <atyfto@google.com>
Commit-Queue: Auto-Submit <auto-submit@fuchsia-infra.iam.gserviceaccount.com>
diff --git a/cmd/recipe_wrapper/README.md b/cmd/recipe_wrapper/README.md
index 58ab46a..a96bf53 100644
--- a/cmd/recipe_wrapper/README.md
+++ b/cmd/recipe_wrapper/README.md
@@ -1,7 +1,7 @@
-# Recipe Bootstrapping
+# Recipe Wrapping
 
-The recipe bootstrapping tool reads a build.proto from stdin, resolves the
-appropriate recipe version to use, and executes the build.
+The recipe wrapping tool reads a build.proto from stdin, resolves the
+appropriate recipe version and properties to use, and executes the build.
 
 The tool implements the
 [luciexe protocol](https://pkg.go.dev/go.chromium.org/luci/luciexe). Fuchsia
@@ -131,9 +131,9 @@
 To circumvent this behavior, you need to build recipe_wrapper locally and
 upload the resulting executable to a file with the special name `luciexe` in the
 led job's isolated input. This work is handled by
-`scripts/led-edit-recipe-bootstrap.py`, which can be pipelined with other led
+`scripts/led-edit-recipe-wrapper.py`, which can be pipelined with other led
 commands. For example:
 
 ```sh
-led get-build 8841535313446777120 | ./scripts/led-edit-recipe-bootstrap.py | led launch
+led get-build 8841535313446777120 | ./scripts/led-edit-recipe-wrapper.py | led launch
 ```
diff --git a/scripts/led-edit-recipe-bootstrap.py b/scripts/led-edit-recipe-wrapper.py
similarity index 84%
rename from scripts/led-edit-recipe-bootstrap.py
rename to scripts/led-edit-recipe-wrapper.py
index adcd6da..df00fe2 100755
--- a/scripts/led-edit-recipe-bootstrap.py
+++ b/scripts/led-edit-recipe-wrapper.py
@@ -3,12 +3,12 @@
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
 """A script for testing recipe_bootstrap using led.
 
-To launch a led job using your local modifications to recipe_bootstrap, run this
+To launch a led job using your local modifications to recipe_wrapper, run this
 from the root of the infra/infra repo:
 
-    led get-build ... | ./scripts/led-edit-recipe-bootstrap.py | led launch
+    led get-build ... | ./scripts/led-edit-recipe-wrapper.py | led launch
 """
 
 import json
@@ -28,7 +28,7 @@
     exe.pop("cipd_package", None)
     exe.pop("cipd_version", None)
 
     # Make sure we build recipe_bootstrap for the correct OS and arch used by
     # the build. This is best-effort, as it encodes infra implementation details
     # (names and allowed values of swarming dimensions) that may change in the
     # future.
@@ -56,8 +56,8 @@
             ["go", "build", "-o", exe_path, "."],
             env={**os.environ, **go_env},
             # `go build` must be run from within the module containing
-            # recipe_bootstrap.
-            cwd=os.path.join(infra_dir, "cmd", "recipe_bootstrap"),
+            # recipe_wrapper.
+            cwd=os.path.join(infra_dir, "cmd", "recipe_wrapper"),
         )
 
         # `led edit-isolated` runs a command in a temporary directory that will
@@ -3,12 +3,12 @@
 # found in the LICENSE file.
 
-"""A script for testing recipe_bootstrap using led.
+"""A script for testing recipe_wrapper using led.
 
@@ -28,7 +28,7 @@
     exe.pop("cipd_version", None)
 
-    # Make sure we build recipe_bootstrap for the correct OS and arch used by
+    # Make sure we build recipe_wrapper for the correct OS and arch used by
     # the build. This is best-effort, as it encodes infra implementation details
     # (names and allowed values of swarming dimensions) that may change in the